pysas
=====

Speech Analysis and Synthesis Toolkit for Python(2.X, 3.X).

Inspired by r9y9's ssp products(https://github.com/r9y9).

This module include
`World <http://ml.cs.yamanashi.ac.jp/world/english/index.html>`__ C++
library by M. Morise.

usage
=====

-  http://nbviewer.ipython.org/github/shunsukeaihara/pysas/blob/master/sample.ipynb

LICENSE
-------

Licensed under MIT License. Bundled World C++ library is licensed under
New BSD license.
